<?php

namespace Drupal\cms_content_sync_views\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;
use Drupal\cms_content_sync\Entity\EntityStatus;
use Drupal\Core\Url;

/**
 * Views Field handler to check if a entity is imported.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("cms_content_sync_sync_state")
 */
class SyncState extends FieldPluginBase {

  /**
   * @{inheritdoc}
   */
  public function query() {
    // Leave empty to avoid a query on this field.
  }

  /**
   * Define the available options.
   *
   * @return array
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    return $options;
  }

  /**
   * Provide the options form.
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
  }

  /**
   * @{inheritdoc}
   *
   * @param \Drupal\views\ResultRow $values
   *
   * @return \Drupal\Component\Render\MarkupInterface|\Drupal\Core\StringTranslation\TranslatableMarkup|\Drupal\views\Render\ViewsRenderPipelineMarkup|string
   */
  public function render(ResultRow $values) {
    $entity = $values->_entity;
    $messages = [];
    // Get the status entity.
    $entity_status = EntityStatus::getInfosForEntity($entity->getEntityTypeId(), $entity->uuid());
    $first_entity_status = reset($entity_status);
    if ($first_entity_status) {

      $pools = '';
      $i = 0;
      $len = count($entity_status);
      foreach ($entity_status as $status) {
        if ($i == $len - 1) {
          $pools .= $status->getPool()->label();
        }
        else {
          $pools .= $status->getPool()->label() . ', ';
        }
        $i++;
      }

      // "Imported from ... at ..."
      // We are checking on LastImported and not on the source entity
      // since we also will have an "imported" date when it comes to cross sync.
      if (!is_null($first_entity_status->getLastImport())) {
        $url = Url::fromUri($first_entity_status->getSourceUrl());
        $link = Link::fromTextAndUrl(t('here'), $url);
        $link = $link->toRenderable();
        $link['#attributes'] = ['target' => '_blank'];
        $link_render = render($link);

        $messages['imported_from'] .= $this->t('Imported from @link at @date.', [
          '@link' => $link_render,
          '@date' => date('d.m.Y - H:i', $first_entity_status->getLastImport()),
        ]);
      }

      // "Exported on ... to ...".
      if (!is_null($first_entity_status->getLastExport())) {
        ;
        $messages['exported_on'] = $this->t('Exported on @date to @pools.', [
          '@date' => date('d.m.Y - H:i', $first_entity_status->getLastExport()),
          '@pools' => $pools,
        ]);
      }

      // @ToDo: "Will be exported to ..."
      //      if ($first_entity_status->isSourceEntity() && is_null($first_entity_status->getLastExport())) {
      //        $messages .= $this->t('Will be exported to @pools', [
      //          '@pools' => $pools
      //        ]);
      //      }
      // "Update waiting to be exported.".
      if (!is_null($first_entity_status->getLastExport()) && $first_entity_status->getLastExport() != $entity->getChangedTime()) {
        $messages['update_waiting'] = $this->t('Update waiting to be exported.');
      }
    }

    $renderable = [
      '#theme' => 'sync_status',
      '#messages' => $messages,
    ];
    $rendered = \Drupal::service('renderer')->render($renderable);

    return $rendered;
  }

}
